/* CopyToClipboard widget styles - following agents.md pattern */
.copy-button-wrapper {
  font-family: system-ui, -apple-system, BlinkMacSystemFont, sans-serif;
  color-scheme: light dark;
  
  /* CSS Variables for theming - light mode defaults */
  --copy-btn-bg: #e0e0e0;
  --copy-btn-bg-hover: #d0d0d0;
  --copy-btn-bg-active: #c0c0c0;
  --copy-btn-text: #1a1a1a;
  --copy-btn-shadow: rgba(0, 0, 0, 0.1);
  --copy-btn-shadow-hover: rgba(0, 0, 0, 0.15);
}

.copy-button {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  gap: 6px;
  padding: 8px 16px;
  font-size: 14px;
  font-weight: 500;
  color: var(--copy-btn-text);
  background-color: var(--copy-btn-bg);
  border: none;
  border-radius: 6px;
  cursor: pointer;
  transition: all 0.2s ease;
  box-shadow: 0 2px 4px var(--copy-btn-shadow);
}

.copy-button:hover {
  background-color: var(--copy-btn-bg-hover);
  box-shadow: 0 4px 8px var(--copy-btn-shadow-hover);
  transform: translateY(-1px);
}

.copy-button:active {
  background-color: var(--copy-btn-bg-active);
  transform: translateY(0);
  box-shadow: 0 1px 2px var(--copy-btn-shadow);
}

.copy-button:focus {
  outline: 2px solid var(--copy-btn-bg);
  outline-offset: 2px;
}

.copy-button:disabled {
  opacity: 0.5;
  cursor: not-allowed;
}

.copy-button-icon {
  width: 16px;
  height: 16px;
  flex-shrink: 0;
}

/* Dark mode styles */
.dark .copy-button-wrapper,
.dark-theme .copy-button-wrapper,
[data-theme="dark"] .copy-button-wrapper {
  --copy-btn-bg: #4a4a4a;
  --copy-btn-bg-hover: #5a5a5a;
  --copy-btn-bg-active: #3a3a3a;
  --copy-btn-text: #ffffff;
  --copy-btn-shadow: rgba(0, 0, 0, 0.3);
  --copy-btn-shadow-hover: rgba(0, 0, 0, 0.4);
}
